# DataWhispers Module

![DataWhispers Logo](https://github.com/GermanPaul12/datawhispers/blob/main/assets/logo.png?raw=true)

## Documentation: [![doc](https://img.shields.io/badge/Made%20with-Sphinx-1f425f.svg)](https://germanpaul12.github.io/datawhispers/) [![Documentation Status](https://readthedocs.org/projects/datawhispers/badge/?version=latest)](https://datawhispers.readthedocs.io/en/latest/?badge=latest)

## Pypi: ![PyPI](https://img.shields.io/pypi/v/datawhispers) ![PyPI - Downloads](https://img.shields.io/pypi/dm/datawhispers)

## Streamlit: [![Streamlit App](https://static.streamlit.io/badges/streamlit_badge_black_white.svg)](https://datawhispers.streamlit.app/)

### The **DataWhispers** module is used for solving regression and statistical problems

It was programmed for exams in advanced programming and data visualisation at DHBW Mannheim

Solve regression problems (lin, poly, trig, free, least_squares), plot the results and mnist numbers or do some statistical analysis with chi2, pearson or student-t

Feel free to check out the [Documentation](https://datawhispers.readthedocs.io/en/latest/index.html)

To install just write ```pip install datawhispers``` in your command prompt of choice
